@@ -1,5 +1,4 @@
 /*
-  
   -----------------------------[ XCF Loader ]-----------------------------
 
   This program is free software; you can redistribute it and/or modify
@@ -43,19 +42,10 @@
   concept of a channel with a layer, since it doesn't really matter.
 
   Ok, hope this helps with understanding XCF.                 -- cK.
-
 */
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <stdio.h>
-#include <string.h>
-#include <sys/types.h>
 #include <netinet/in.h>
 
-#include "loader_common.h"
+#include "Imlib2_Loader.h"
 #include "loader_xcf.h"
 
 #define XCF_DBG 0
@@ -65,6 +55,8 @@
 #define D(fmt...)
 #endif
 
+static const char  *const _formats[] = { "xcf" };
+
 #define TILE_WIDTH   64
 #define TILE_HEIGHT  64
 
@@ -1572,18 +1564,21 @@ xcf_to_imlib(ImlibImage * im)
 {
    im->w = image->width;
    im->h = image->height;
-   IM_FLAG_SET(im, F_HAS_ALPHA);
+   im->has_alpha = 1;
 
    im->data = image->data;
 }
 
-int
-load2(ImlibImage * im, int load_data)
+static int
+_load(ImlibImage * im, int load_data)
 {
    int                 rc = LOAD_FAIL;
 
+   if (!im->fi->fp)
+      return LOAD_FAIL;
+
    /* initialize */
-   if (!xcf_file_init(im->fp))
+   if (!xcf_file_init(im->fi->fp))
       return LOAD_FAIL;
 
    /* do it! */
@@ -1606,10 +1601,4 @@ load2(ImlibImage * im, int load_data)
    return rc;
 }
 
-void
-formats(ImlibLoader * l)
-{
-   static const char  *const list_formats[] = { "xcf" };
-   __imlib_LoaderSetFormats(l, list_formats,
-                            sizeof(list_formats) / sizeof(char *));
-}
+IMLIB_LOADER(_formats, _load, NULL);
